@@ -44,7 +44,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         self.sound15=mixer.Sound("/home/opt/maelophone/stylo_smpl/a#2.wav") #a sharp
         self.sound2=mixer.Sound("/home/opt/maelophone/stylo_smpl/b2.wav")      #b
         self.sound3=mixer.Sound("/home/opt/maelophone/stylo_smpl/c3.wav")      #c
-        self.sound35=mixer.Sound("/home/opt/maelophon/estylo_smpl/c#3.wav")      #c sharp
+        self.sound35=mixer.Sound("/home/opt/maelophon/stylo_smpl/c#3.wav")      #c sharp
         self.sound4=mixer.Sound("/home/opt/maelophone/stylo_smpl/d3.wav")      #d
         self.sound45=mixer.Sound("/home/opt/maelophone/stylo_smpl/d#3.wav")  #d sharp
         self.sound5=mixer.Sound("/home/opt/maelophone/stylo_smpl/e3.wav")       #e
